@@ -1,6 +1,10 @@
-'V1.12.01-Tqdm.desc.jitter.timer'
-__all__ = ['B','Blank','BB','bbfy','C','choose','crop_from_bb','cv2', 'dumpdill','df2bbs','diff',
-'flatten','fname','fname2','glob','Glob','inspect','jitter', 'L',
+'V1.12.04'
+'''Change Log
+bbs in show will accept a numpy array
+show image torch tensor bug
+'''
+__all__ = ['B','Blank','BB','bbfy','C','choose','crop_from_bb','cv2', 'dumpdill','df2bbs','diff','find',
+'flatten','fname','find','fname2','glob','Glob','inspect','jitter', 'L',
 'line','loaddill','logger','extn', 'makedir', 'np', 'now','nunique','os','pd','parent','Path','pdb',
 'plt','puttext','randint', 'rand', 'read','rect','rename_batch', 'see','show','stem','stems','sys','tqdm','Tqdm','Timer','unique','uint']
 
@@ -38,7 +42,7 @@ class Timer:
 
     def __call__(self, ix, info=None):
         elapsed = time.time() - self.start
-        print('\r{}{}/{} ({:.2f}s - {:.2f}s remaining)'.format(info, ix+1, self.N, elapsed, (self.N-ix)*(elapsed/(ix+1))), end='')
+        print('\r{}\t{}/{} ({:.2f}s - {:.2f}s remaining)'.format(info, ix+1, self.N, elapsed, (self.N-ix)*(elapsed/(ix+1))), end='')
 
 line = lambda N=66: print('='*N)
 def see(*X, N=66): list(map(lambda x: print('='*N+'\n{}'.format(x)), X))+[print('='*N)]
@@ -52,6 +56,16 @@ def choose(List, n=1):
         np.random.shuffle(_ns)
         return [List[ix] for ix in _ns[:n]]
 rand = lambda : ''.join(choose(list('1234567890qwertyuiopasdfghjklzxcvbnmQWERTYUIOPASDFGHJKLZXCVBNM'), n=6))
+def find(item, List):
+    '''Find an `item` in a `List`
+    >>> find('abc', ['ijk','asdfs','dfsabcdsf','lmnop'])
+    'dgsabcdsf'
+    >>> find('file1', ['/tmp/file0.jpg', '/tmp/file0.png', '/tmp/file1.jpg', '/tmp/file1.png', '/tmp/file2.jpg', '/tmp/file2.png'])
+    ['/tmp/file1.jpg', '/tmp/file1.png']
+    '''
+    filtered = [i for i in List if item in i]
+    if len(filtered) == 1: return filtered[0]
+    return filtered
 def inspect(*arrays, **kwargs):
     '''
     shows shape, min, max and mean of an array/list of oreys
@@ -172,7 +186,7 @@ def show(img=None, ax=None, title=None, sz=None, bbs=None, confs=None,
          save_path=None, text_sz=15, df=None, **kwargs):
     'show an image'
     try:
-        if isinstance(img, torch.Tensor) and (img.device.type == 'cuda'): img = img.cpu()
+        if isinstance(img, torch.Tensor): img = img.cpu().detach().numpy().copy()
     except: ...
     img = np.copy(img)
     if img.max() == 255: img = img.astype(np.uint8)
@@ -210,6 +224,7 @@ def show(img=None, ax=None, title=None, sz=None, bbs=None, confs=None,
         # colors = [[int(i*255) for i in c.get_rgb()] for c in colors]
         colors = [[255, 0, 0], [223, 111, 0], [191, 191, 0], [79, 159, 0], [0, 128, 0]]
         bb_colors = [colors[ int(cnf*5)-1 ] for cnf in confs]
+    if isinstance(bbs, np.ndarray): bbs = bbs.astype(np.uint16).tolist()
     if bbs:
         'rect-th'
         if 'th' in kwargs:
@@ -296,7 +311,7 @@ class BB:
 df2bbs = lambda df: [BB(bb) for bb in df[list('xyXY')].values.tolist()]
 def bbfy(bbs): return [BB(bb) for bb in bbs]
 def jitter(bbs, noise):
-    return [bb.jitter(noise) for bb in bbs]
+    return [BB(bb).jitter(noise) for bb in bbs]
 
 class L(list):
     def __getitem__(self, keys):
