@@ -1,11 +1,13 @@
-'v0.15.2'
+'v0.15.2+0.75'
 '''Todo - v0.15.3
 - [x] Make Colab compatible
 - [ ] have a better keyword for transient log (`temp`)
 - [ ] accumulate values
 - [x] convert to numpy if torch value is sent
-- [ ] use regexs for plotting metrics
-- [ ] add .plot_epochs()
+- [x] use regexs for plotting metrics
+- [x] add .plot_epochs()
+- [x] moving average
+- [x] plot can accept axis
 '''
 
 __all__ = ['torch','nn','np','F','Dataset','DataLoader','optim','Report']
@@ -17,12 +19,13 @@ from torch.nn import functional as F
 from torch.utils.data import Dataset, DataLoader
 import time, numpy as np, matplotlib.pyplot as plt
 from collections import namedtuple, defaultdict
+import re
 
 metric = namedtuple('metric', 'pos,val'.split(','))
 info = lambda report: '\t'.join([f'{k}: {v:.3f}' for k,v in report.items()])
 
 def to_np(x):
-    if isinstance(x, torch.Tensor): return x.cpu().numpy()
+    if isinstance(x, torch.Tensor): return x.detach().cpu().numpy()
     else:
         return x
 
@@ -44,15 +47,24 @@ class Report:
                 self.logged.append(k)
         self.report_metrics(pos, **metrics)
 
-    def plot(self, keys:list=None):
+    def plot(self, keys:[list,str]=None, smooth=0, ax=None):
+        _show = True if ax is None else False
+        if ax is None:
+            fig, ax = plt.subplots(figsize=kwargs.get('figsize', sz))
+
         keys = self.logged if keys is None else keys
+        if isinstance(keys, str):
+            key_pattern = keys
+            keys = [key for key in self.logged if re.search(key_pattern, key)]
+            
         for k in keys:
             xs, ys = list(zip(*getattr(self,k)))
-            plt.plot(xs, ys, label=k)
-        plt.grid(True)
-        plt.xlabel('Epochs'); plt.ylabel('Metrics')
-        plt.legend()
-        plt.show()
+            if smooth: ys = moving_average(np.array(ys), smooth)
+            ax.plot(xs, ys, label=k)
+        ax.grid(True)
+        ax.set_xlabel('Epochs'); ax.set_ylabel('Metrics')
+        ax.legend()
+        if _show: plt.show()
 
     def history(self, k):
         return [v for _,v in getattr(self,k)]
@@ -102,3 +114,11 @@ class Report:
             print(f'\r{log}{current_iteration}{info(report)}{elapsed}', end='')
         else:
             print(f'\r{log}{current_iteration}{info(report)}{elapsed}', end=end)
+
+def moving_average(a, n=3) :
+    b = np.zeros_like(a)
+    ret = np.cumsum(a, dtype=float)
+    ret[n:] = ret[n:] - ret[:-n]
+    _n = len(b) - n
+    b[-_n-1:] = ret[(n-1):] / n
+    return b
\ No newline at end of file
